import { TypeRegistry } from '@polkadot/types';
import { SignerPayloadJSON, SignerPayloadRaw, SignerResult } from '@polkadot/types/types';
import { PolkadotSigner, SigningManager } from '@polymathnetwork/signing-manager-types';
import { AddressedVaultKey } from '../types';
import { HashicorpVault } from './hashicorp-vault';
export declare class VaultSigner implements PolkadotSigner {
    private readonly vault;
    private readonly registry;
    private currentId;
    /**
     * @hidden
     */
    constructor(vault: HashicorpVault, registry: TypeRegistry);
    /**
     * Sign a payload
     */
    signPayload(payload: SignerPayloadJSON): Promise<SignerResult>;
    /**
     * Sign raw data
     */
    signRaw(raw: SignerPayloadRaw): Promise<SignerResult>;
    /**
     * @hidden
     *
     * Use the Vault to sign raw data and return the signature + update ID
     */
    private signData;
    /**
     * @hidden
     *
     * Get a key from the Vault
     *
     * @param address - SS58 formatted address
     *
     * @throws if there is no key with that address
     */
    private getVaultKey;
}
export declare class HashicorpVaultSigningManager implements SigningManager {
    private externalSigner;
    private vault;
    private _ss58Format?;
    /**
     * Create an instance of the Hashicorp Vault Signing Manager
     *
     * @param args.url - points to where the Vault's transit engine is hosted (usually `<base-url>/v1/transit`)
     * @param args.token - authentication token used for signing
     */
    constructor(args: {
        url: string;
        token: string;
    });
    /**
     * Set the SS58 format in which returned addresses will be encoded
     */
    setSs58Format(ss58Format: number): void;
    /**
     * Return the addresses of all Accounts in the Hashicorp Vault
     *
     * @throws if called before calling `setSs58Format`. Normally, `setSs58Format` will be called by the SDK when instantiated
     */
    getAccounts(): Promise<string[]>;
    /**
     * Return a signer object that uses the underlying keyring pairs to sign
     */
    getExternalSigner(): PolkadotSigner;
    /**
     * Return the information about each key available to sign extrinsics with in the Hashicorp Vault.
     *
     * @throws if called before calling `setSs58Format`. Normally, `setSs58Format` will be called by the SDK when instantiated
     */
    getVaultKeys(): Promise<AddressedVaultKey[]>;
    /**
     * @hidden
     *
     * @throws if the SS58 format hasn't been set yet
     */
    private getSs58Format;
}
