import { HexString } from '@polkadot/util/types';
import { SignRequestPayload, VaultKey } from './types';
export declare class HashicorpVault {
    private readonly url;
    private headers;
    /**
     * @hidden
     */
    constructor(url: string, token: string);
    /**
     * @hidden
     *
     * Assemble URL from separate path strings
     */
    private getUrl;
    /**
     * Retrieve all public keys (hex) stored in the Vault with their respective names and versions
     */
    fetchAllKeys(): Promise<VaultKey[]>;
    /**
     * Retrieve all the public keys (hex formatted) associated to a name, and their versions
     *
     * @param name - name of the key for which to fetch the public keys
     */
    fetchKeysByName(name: string): Promise<VaultKey[]>;
    /**
     * Sign data on behalf of a key and return the hex signature
     *
     * @param name - name of the key that will sign
     * @param version - version of the named key to use
     * @param data - data that will be signed
     */
    signData(name: string, data: SignRequestPayload): Promise<HexString>;
    /**
     *
     * @param res
     */
    private assertResponseOk;
}
